@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploaderTemplate.h 2084 2006-11-25 17:00:47Z svn $
+ * $Id: UploaderTemplate.h 2144 2006-11-29 14:54:20Z svn $
  *****************************************************************************/
 
 #ifndef UPLOADER_TEMPLATE_H
@@ -41,6 +41,7 @@ using namespace std;
 class TemplateLexer;
 class TemplateVariableCreator;
 class UploadItemVariableCreator;
+class ThumbnailVariableCreator;
 
 /**
  * @brief アップローダのテンプレートを表すクラス
@@ -78,6 +79,10 @@ public:
     {
         return item_var_creator_;
     };
+    ThumbnailVariableCreator *get_thumbnail_var_creator() const
+    {
+        return thumbnail_var_creator_;
+    };
 
 private:
     typedef TemplateLexer               Lexer;
@@ -92,7 +97,8 @@ private:
 
     apr_shm_t *node_shm_;
     apr_shm_t *ids_and_keys_shm_;
-    apr_shm_t *var_creator_shm_;
+    apr_shm_t *item_var_creator_shm_;
+    apr_shm_t *thumbnail_var_creator_shm_;
 
     const node_t *node_tree_;
     const char **ids_;
@@ -100,6 +106,7 @@ private:
     apr_size_t key_count_;
 
     UploadItemVariableCreator *item_var_creator_;
+    ThumbnailVariableCreator *thumbnail_var_creator_;
 };
 
 #endif
