@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: Base64FileWriter.cpp 2175 2006-12-06 17:27:48Z svn $
+ * $Id: Base64FileWriter.cpp 2244 2006-12-11 17:25:42Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -34,7 +34,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2175 2006-12-06 17:27:48Z svn $");
+SOURCE_INFO_ADD("$Id: Base64FileWriter.cpp 2244 2006-12-11 17:25:42Z svn $");
 #endif
 
 template<class W> const unsigned char
@@ -65,13 +65,15 @@ Base64FileWriter<W>::Base64FileWriter(apr_pool_t *pool, apr_file_t *file,
  *****************************************************************************/
 template<class W>
 void Base64FileWriter<W>::write_impl(unsigned char *buffer,
-                                     apr_size_t *size)
+                                     apr_size_t *buffer_size)
 {
+    apr_size_t size;
     apr_size_t write_size;
     unsigned char c;
 
+    size = *buffer_size;
     write_size = 0;
-    for (apr_size_t i = 0; i < *size; i++) {
+    for (apr_size_t i = 0; i < size; i++) {
         c = buffer[i];
 
         if (c == '=') {
@@ -105,7 +107,7 @@ void Base64FileWriter<W>::write_impl(unsigned char *buffer,
     }
 
     writer_impl_.write(buffer, write_size);
-    *size = write_size;
+    *buffer_size = write_size;
 }
 
 
