@@ -22,11 +22,13 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: ImageFile.cpp 2089 2006-11-26 04:08:08Z svn $
+ * $Id: ImageFile.cpp 2246 2006-12-12 15:06:22Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
 
+#ifdef MAKE_THUMBNAIL
+
 #ifdef _MSC_VER
 #pragma warning(push)
 #pragma warning(disable:4251)
@@ -49,7 +51,7 @@
 #include "ImageFile.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: ImageFile.cpp 2089 2006-11-26 04:08:08Z svn $");
+SOURCE_INFO_ADD("$Id: ImageFile.cpp 2246 2006-12-12 15:06:22Z svn $");
 
 /******************************************************************************
  * public メソッド
@@ -63,7 +65,12 @@ ImageFile::ImageFile(apr_pool_t *pool, const char *file_path)
     open(APR_READ);
     file_map = mmap();
 
-    image_ = new Magick::Image(Magick::Blob(file_map->mm, file_map->size));
+    try {
+        image_ = new Magick::Image(Magick::Blob(file_map->mm, file_map->size));
+    } catch(exception &e) {
+        // File の資源は APR のプールが管理しているので問題ない
+        throw e.what();
+    }
 }
 
 ImageFile::~ImageFile()
@@ -209,6 +216,8 @@ void run_all(apr_pool_t *pool, int argc, const char * const *argv)
 
 #endif
 
+#endif
+
 // Local Variables:
 // mode: c++
 // coding: utf-8-dos
