@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: RFC2822Parser.cpp 2175 2006-12-06 17:27:48Z svn $
+ * $Id: RFC2822Parser.cpp 2193 2006-12-09 01:26:55Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -39,7 +39,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2175 2006-12-06 17:27:48Z svn $");
+SOURCE_INFO_ADD("$Id: RFC2822Parser.cpp 2193 2006-12-09 01:26:55Z svn $");
 #endif
 
 #define AS_CONTENT(pointer)         reinterpret_cast<content_t *>(pointer)
@@ -301,7 +301,7 @@ void run_parse(apr_pool_t *pool, const char *post_file_path,
                apr_size_t dump_level)
 {
     apr_array_header_t *content_array;
-    RequestReader::progress_t progress;
+    RequestReader::post_progress_t progress;
     ifstream stream(post_file_path, ios_base::binary);
     RFC2822ParserImpl::content_t *file_content;
 
