@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: UploadItemManager.cpp 2169 2006-12-04 16:26:56Z svn $
+ * $Id: UploadItemManager.cpp 2173 2006-12-06 16:12:56Z svn $
  *****************************************************************************/
 
 #include "Environment.h"
@@ -47,7 +47,7 @@
 #include "Macro.h"
 #include "SourceInfo.h"
 
-SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2169 2006-12-04 16:26:56Z svn $");
+SOURCE_INFO_ADD("$Id: UploadItemManager.cpp 2173 2006-12-06 16:12:56Z svn $");
 
 #ifdef DEBUG
 #include <iostream>
@@ -103,8 +103,8 @@ apr_size_t UploadItemManager::add(apr_pool_t *pool,
          file_name, file_mime, file_digest, remove_pass, download_pass,
          comment);
 
-    // 一番古いアイテムを削除
-    if (item_list_->is_full()) {
+    // 古いアイテムを削除
+    while (item_list_->is_full(file_size)) {
         UploadItem *old_uitem;
 
         old_uitem = AS_UITEM(item_list_->get_by_index(item_list_->size()-1));
