@@ -22,7 +22,7 @@
  * 3. This notice may not be removed or altered from any source
  *    distribution.
  *
- * $Id: uploader_handler.cpp 2247 2006-12-13 03:32:32Z svn $
+ * $Id: uploader_handler.cpp 2271 2006-12-16 20:15:22Z svn $
  *****************************************************************************/
 
 #ifndef TEMPLATE_INSTANTIATION
@@ -56,7 +56,7 @@
 #include "SourceInfo.h"
 
 #ifndef TEMPLATE_INSTANTIATION
-SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2247 2006-12-13 03:32:32Z svn $");
+SOURCE_INFO_ADD("$Id: uploader_handler.cpp 2271 2006-12-16 20:15:22Z svn $");
 #endif
 
 #define IS_REQUEST_COMMAND(arg, command) \
@@ -270,14 +270,22 @@ static int thumbnail_view(typename Response::Handle *r, UploaderConfig *config,
                           const char *arg)
 {
     apr_size_t item_id;
+    const char *file_name;
+    const char *item_id_str;
 
+    file_name = get_word(r->pool, &arg, ARG_SEPARATE_STR[0]);
+    if (strlen(file_name) == 0) {
+        return HTTP_BAD_REQUEST;
+    }
+
+    item_id_str = apr_pstrdup(r->pool, file_name);
     item_id = static_cast<apr_size_t>
-        (apr_atoi64(get_word(r->pool, &arg, ARG_SEPARATE_STR[0])));
+        (apr_atoi64(get_word(r->pool, &item_id_str, FILE_EXT_SEPARATOR[0])));
 
     try {
         const char  *thumb_file_path;
 
-        Response::set_content_type(r, get_image_mime(THUMBNAIL_FILE_TYPE));
+        Response::set_content_type(r, get_image_mime(file_name));
 #ifndef DEBUG
         Response::set_modified_time(r,
                                     config->get_item_manager()->get_mtime());
